package com.abi.qms.platform.dto.req;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.Accessors;
import org.jetbrains.annotations.NotNull;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author: zhang zhao
 * @date: 2021/8/510:41
 * @description: 关联已有案件入参
 */
@Data
@NoArgsConstructor
@ApiModel
public class AssociatedWithCaseReq implements Serializable {

    @ApiModelProperty("案件ID")
    @NotNull
    private Long caseId;

    @ApiModelProperty("箱码")
    @NotBlank
    private String boxCode;


    @ApiModelProperty("skuCode")
    @NotBlank
    private String skuCode;

    @ApiModelProperty("流向信息列表")
    @NotEmpty
    private List<FlowBean> flowList;

    /**
     * 流向信息
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    @ToString
    public static class FlowBean implements Serializable {
        @ApiModelProperty("节点标识")
        @NotNull
        private Long nodeId;

        @ApiModelProperty("节点名称")
        private String nodeName;


        @ApiModelProperty("入库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime inStorageTime;

        @ApiModelProperty("出库时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime outStorageTime;
    }


}
